<?php
$TRANSLATIONS = array(
"Could not load template" => "Kunne ikke indlæse skabelon",
"Saved" => "Gemt",
"Reset" => "Nulstil",
"An error occurred" => "Der opstod en fejl",
"Sharing email - public link shares (HTML)" => "Deling af e-mail - offentlig deling af links (HTML)",
"Sharing email - public link shares (plain text fallback)" => "Deling af e-mail - offentlig deling af links (simpel tekstudgave)",
"Sharing email (HTML)" => "E-mail for deling (HTML)",
"Sharing email (plain text fallback)" => "E-mail for deling (ren tekst ved tilbagefald)",
"Lost password mail" => "Mail for mistet kodeord",
"New user email (HTML)" => "E-mail om ny bryger (HTML)",
"New user email (plain text fallback)" => "E-mail om ny bruger (fald tilbage på ren tekst)",
"Activity notification mail" => "Mail for notifikation om aktivitet",
"Mail Templates" => "Mailskabeloner",
"Theme" => "Tema",
"Template" => "Skabelon",
"Please choose a template" => "Vælg venligst en skabelon",
"Save" => "Gem"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
